@@ -3,7 +3,7 @@ import requests
 
 
 class Cerebrate:
-    def __init__(self, api_key: str, url: str = 'https://app.metadialog.com/api/predict'):
+    def __init__(self, api_key: str, url: str = 'https://app.cerebrate.ai/api/predict'):
         self._api_key = api_key
         self._url = url
 
